==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/BitbucketWebHookCauseFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class BitbucketWebHookCauseFluentImpl<A extends io.fabric8.openshift.api.model.BitbucketWebHookCauseFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.BitbucketWebHookCauseFluent<A>{
  public BitbucketWebHookCauseFluentImpl() {
  }
  public BitbucketWebHookCauseFluentImpl(io.fabric8.openshift.api.model.BitbucketWebHookCause instance) {
    this.withRevision(instance.getRevision()); 
    this.withSecret(instance.getSecret()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.SourceRevisionBuilder revision;
  private java.lang.String secret;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildRevision instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.SourceRevision getRevision() {
    return this.revision!=null?this.revision.build():null;
  }
  public io.fabric8.openshift.api.model.SourceRevision buildRevision() {
    return this.revision!=null?this.revision.build():null;
  }
  public A withRevision(io.fabric8.openshift.api.model.SourceRevision revision) {
    _visitables.get("revision").remove(this.revision);
    if (revision!=null){ this.revision= new io.fabric8.openshift.api.model.SourceRevisionBuilder(revision); _visitables.get("revision").add(this.revision);} return (A) this;
  }
  public java.lang.Boolean hasRevision() {
    return this.revision != null;
  }
  public io.fabric8.openshift.api.model.BitbucketWebHookCauseFluent.RevisionNested<A> withNewRevision() {
    return new io.fabric8.openshift.api.model.BitbucketWebHookCauseFluentImpl.RevisionNestedImpl();
  }
  public io.fabric8.openshift.api.model.BitbucketWebHookCauseFluent.RevisionNested<A> withNewRevisionLike(io.fabric8.openshift.api.model.SourceRevision item) {
    return new io.fabric8.openshift.api.model.BitbucketWebHookCauseFluentImpl.RevisionNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.BitbucketWebHookCauseFluent.RevisionNested<A> editRevision() {
    return withNewRevisionLike(getRevision());
  }
  public io.fabric8.openshift.api.model.BitbucketWebHookCauseFluent.RevisionNested<A> editOrNewRevision() {
    return withNewRevisionLike(getRevision() != null ? getRevision(): new io.fabric8.openshift.api.model.SourceRevisionBuilder().build());
  }
  public io.fabric8.openshift.api.model.BitbucketWebHookCauseFluent.RevisionNested<A> editOrNewRevisionLike(io.fabric8.openshift.api.model.SourceRevision item) {
    return withNewRevisionLike(getRevision() != null ? getRevision(): item);
  }
  public java.lang.String getSecret() {
    return this.secret;
  }
  public A withSecret(java.lang.String secret) {
    this.secret=secret; return (A) this;
  }
  public java.lang.Boolean hasSecret() {
    return this.secret != null;
  }
  
  /**
   * Method is deprecated. use withSecret instead.
   */
  @java.lang.Deprecated
  public A withNewSecret(java.lang.String arg0) {
    return (A)withSecret(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    BitbucketWebHookCauseFluentImpl that = (BitbucketWebHookCauseFluentImpl) o;
    if (revision != null ? !revision.equals(that.revision) :that.revision != null) return false;
    if (secret != null ? !secret.equals(that.secret) :that.secret != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(revision,  secret,  additionalProperties,  super.hashCode());
  }
  public class RevisionNestedImpl<N> extends io.fabric8.openshift.api.model.SourceRevisionFluentImpl<io.fabric8.openshift.api.model.BitbucketWebHookCauseFluent.RevisionNested<N>> implements io.fabric8.openshift.api.model.BitbucketWebHookCauseFluent.RevisionNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    RevisionNestedImpl(io.fabric8.openshift.api.model.SourceRevision item) {
      this.builder = new io.fabric8.openshift.api.model.SourceRevisionBuilder(this, item);
    }
    RevisionNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.SourceRevisionBuilder(this);
    }
    io.fabric8.openshift.api.model.SourceRevisionBuilder builder;
    public N and() {
      return (N) BitbucketWebHookCauseFluentImpl.this.withRevision(builder.build());
    }
    public N endRevision() {
      return and();
    }
    
  }
  
}

==> openshift-model-5.12.1-sources.jar: io/fabric8/openshift/api/model/BitbucketWebHookCauseFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class BitbucketWebHookCauseFluentImpl<A extends io.fabric8.openshift.api.model.BitbucketWebHookCauseFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.BitbucketWebHookCauseFluent<A>{
  public BitbucketWebHookCauseFluentImpl() {
  }
  public BitbucketWebHookCauseFluentImpl(io.fabric8.openshift.api.model.BitbucketWebHookCause instance) {
    this.withRevision(instance.getRevision()); 
    this.withSecret(instance.getSecret()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.SourceRevisionBuilder revision;
  private java.lang.String secret;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildRevision instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.SourceRevision getRevision() {
    return this.revision!=null?this.revision.build():null;
  }
  public io.fabric8.openshift.api.model.SourceRevision buildRevision() {
    return this.revision!=null?this.revision.build():null;
  }
  public A withRevision(io.fabric8.openshift.api.model.SourceRevision revision) {
    _visitables.get("revision").remove(this.revision);
    if (revision!=null){ this.revision= new io.fabric8.openshift.api.model.SourceRevisionBuilder(revision); _visitables.get("revision").add(this.revision);} return (A) this;
  }
  public java.lang.Boolean hasRevision() {
    return this.revision != null;
  }
  public io.fabric8.openshift.api.model.BitbucketWebHookCauseFluent.RevisionNested<A> withNewRevision() {
    return new io.fabric8.openshift.api.model.BitbucketWebHookCauseFluentImpl.RevisionNestedImpl();
  }
  public io.fabric8.openshift.api.model.BitbucketWebHookCauseFluent.RevisionNested<A> withNewRevisionLike(io.fabric8.openshift.api.model.SourceRevision item) {
    return new io.fabric8.openshift.api.model.BitbucketWebHookCauseFluentImpl.RevisionNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.BitbucketWebHookCauseFluent.RevisionNested<A> editRevision() {
    return withNewRevisionLike(getRevision());
  }
  public io.fabric8.openshift.api.model.BitbucketWebHookCauseFluent.RevisionNested<A> editOrNewRevision() {
    return withNewRevisionLike(getRevision() != null ? getRevision(): new io.fabric8.openshift.api.model.SourceRevisionBuilder().build());
  }
  public io.fabric8.openshift.api.model.BitbucketWebHookCauseFluent.RevisionNested<A> editOrNewRevisionLike(io.fabric8.openshift.api.model.SourceRevision item) {
    return withNewRevisionLike(getRevision() != null ? getRevision(): item);
  }
  public java.lang.String getSecret() {
    return this.secret;
  }
  public A withSecret(java.lang.String secret) {
    this.secret=secret; return (A) this;
  }
  public java.lang.Boolean hasSecret() {
    return this.secret != null;
  }
  
  /**
   * Method is deprecated. use withSecret instead.
   */
  @java.lang.Deprecated
  public A withNewSecret(java.lang.String arg0) {
    return (A)withSecret(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    BitbucketWebHookCauseFluentImpl that = (BitbucketWebHookCauseFluentImpl) o;
    if (revision != null ? !revision.equals(that.revision) :that.revision != null) return false;
    if (secret != null ? !secret.equals(that.secret) :that.secret != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(revision,  secret,  additionalProperties,  super.hashCode());
  }
  public class RevisionNestedImpl<N> extends io.fabric8.openshift.api.model.SourceRevisionFluentImpl<io.fabric8.openshift.api.model.BitbucketWebHookCauseFluent.RevisionNested<N>> implements io.fabric8.openshift.api.model.BitbucketWebHookCauseFluent.RevisionNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    RevisionNestedImpl(io.fabric8.openshift.api.model.SourceRevision item) {
      this.builder = new io.fabric8.openshift.api.model.SourceRevisionBuilder(this, item);
    }
    RevisionNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.SourceRevisionBuilder(this);
    }
    io.fabric8.openshift.api.model.SourceRevisionBuilder builder;
    public N and() {
      return (N) BitbucketWebHookCauseFluentImpl.this.withRevision(builder.build());
    }
    public N endRevision() {
      return and();
    }
    
  }
  
}
